#! /bin/sh
# Generated by clamav.SlackBuild for clamav-0.91.2-i486-1McD.tgz on 22-Aug-2007
# By Martijn Dekker <martijn@inlv.org>
# Based on install script by Jim Simmons for ClamAV 0.81.

function upd_conf {
 	# If there's no config file by that name, mv it over:
 	if ! test -e $1; then
 		mv $1.new $1
 	elif diff -q $1 $1.new; then	# toss the redundant copy
 		rm $1.new
 	elif ! test -s $1.new; then
 		rm $1.new   # do not keep empty initial files (e.g. log)
 	fi
 	# Otherwise, we leave the .new copy for the admin to consider...
}

function free_user_id {
 	# Find a free user-ID >= 100 (should be < 1000 so it's not a normal user)
 	local FREE_USER_ID=100
 	while grep -q "^.*:.*:$FREE_USER_ID:.*:.*:.*:" etc/passwd; do
 		let FREE_USER_ID++
 	done
 	echo $FREE_USER_ID
}

# Figure out our root directory
ROOTDIR=$(pwd)
unset CHROOT
if test "$ROOTDIR" != "/"; then
 	CHROOT="chroot $ROOTDIR "
 	ROOTDIR="${ROOTDIR}/"
fi

# Edit config file with currently used user/group
# (it's not worth leaving a .new file over)
if test -f etc/clamd.conf && ! grep -qE '^User[[:blank:]]+clamav[[:blank:]]*$' etc/clamd.conf
then
 	TMPFILE=$(mktemp /tmp/clamav.XXXXXX)
 	sed '	/^User[[:blank:]]/	s/[[:blank:]].*/ clamav/
 		' etc/clamd.conf > $TMPFILE
 	cmp -s $TMPFILE etc/clamd.conf
 	if test $? = 1; then
 		echo "Changing user in ${ROOTDIR}etc/clamd.conf to [1mclamav[0m." 1>&2
 		cat $TMPFILE > etc/clamd.conf
 	fi
 	rm $TMPFILE
fi

# Set up group if needed
grep -q '^clamav:' etc/group || $CHROOT /usr/sbin/groupadd clamav

# Set up user: add it if it doesn't exist, update it if it already does.
# In any case, make sure it has or gets a user ID between 100 and 999.
# If username changed, determine old username so we can change it (look
# for entry with homedir /var/lib/clamav).
if OLD_ENTRY=$(grep -m 1 '^clamav:' etc/passwd) \
 	|| OLD_ENTRY=$(grep -m 1 ':/var/lib/clamav:[a-z/]*$' etc/passwd)
then
 	# Modify existing user
 	OLD_USER=$(echo $OLD_ENTRY | cut -f 1 -d ':')
 	USER_ID=$(echo $OLD_ENTRY | cut -f 3 -d ':')
 	test $USER_ID -ge 1000 && USER_ID=$(free_user_id)
 	if test "$OLD_USER" = "clamav"; then
 		echo -n "Updating unprivileged user" 1>&2
 	else
 		echo -n "Changing unprivileged user [1m$OLD_USER[0m to" 1>&2
 	fi
 	$CHROOT /usr/sbin/usermod \
 		-l clamav \
 		-g clamav \
 		-d /var/lib/clamav \
 		-u $USER_ID \
 		-s /bin/false \
 		-c "ClamAV Antivirus Daemon" \
 		$OLD_USER
else
 	# Add new user
 	echo -n "Creating unprivileged user" 1>&2
 	$CHROOT /usr/sbin/useradd \
 		-g clamav \
 		-d /var/lib/clamav \
 		-u $(free_user_id) \
 		-s /bin/false \
 		-c "ClamAV Antivirus Daemon" \
 		clamav
fi
echo " [1mclamav[0m (group [1mclamav[0m) to run the daemon." 1>&2

# Set up permissions
$CHROOT /bin/chown -R clamav:clamav \
 	/var/lib/clamav \
 	/var/run/clamav-milter \
 	/var/log/clamav-update.new \
 	/var/log/clamd.new
$CHROOT /bin/chown root:clamav \
 	/usr/sbin/clamav-milter \
 	/usr/sbin/clamd

# Generate Sendmail .mc and .cf files with support for the ClamAV milter
CLMILTER_MC_CMD="dnl# ClamAV milter integration from clamav-0.91.2-i486-1McD.tgz:
INPUT_MAIL_FILTER(\`clamav', \`S=local:/var/run/clamav-milter/milter.sock, F=, T=S:4m;R:4m')dnl
define(\`confINPUT_MAIL_FILTERS', \`clamav')dnl
"
if test -r usr/share/sendmail/cf/cf/sendmail-slackware.mc &&
 	test -x usr/sbin/sendmail && test -x usr/bin/m4
then
 	cd usr/share/sendmail/cf/cf

 	for NAME in sendmail-slackware-tls sendmail-slackware-tls-sasl sendmail-slackware ; do
 		SLACK_MC=$NAME.mc
 		CLAM_MC=$NAME-clamav.mc
 		CLAM_CF=$NAME-clamav.cf
 		if test -f $SLACK_MC; then
 			echo "Generating ${ROOTDIR}usr/share/sendmail/$CLAM_CF ..."
 			sed "/VERSIONID/ s/')dnl/ with ClamAV milter support')dnl/" $SLACK_MC > $CLAM_MC
 			echo "$CLMILTER_MC_CMD" >> $CLAM_MC
 			m4 ../m4/cf.m4 $CLAM_MC > ../../$CLAM_CF 2> /dev/null
 		else
 			echo "WARNING: Cannot generate ${ROOTDIR}usr/share/sendmail/$CLAM_CF because"
 			echo "	 the file ${ROOTDIR}usr/share/sendmail/cf/cf/$SLACK_MC doesn't exist."
 			rm $CLAM_MC $CLAM_CF	# remove dummies
 		fi
 	done

 	cd ../../../../..
 	echo "	[36mTo enable Sendmail integration, copy one of these .cf files to[0m"
 	echo "	[36m${ROOTDIR}etc/mail/sendmail.cf, then start ClamAV and restart Sendmail.[0m"
else
 	# if we can't make 'em, remove the dummies
 	for NAME in sendmail-slackware-tls sendmail-slackware-tls-sasl sendmail-slackware ; do
 		rm usr/share/sendmail/$NAME-clamav.cf usr/share/sendmail/cf/cf/$NAME-clamav.mc
 	done
 	echo "[1;31mWARNING: [0mThe ClamAV-enabled config files for Sendmail could not be generated."
 	echo "	 If you want ClamAV to work with Sendmail, first make sure the"
 	echo "	 [1msendmail[0m, [1msendmail-cf[0m, and [1mm4[0m packages for Slackware are installed,"
 	echo "	 and then do: [31m# [32mupgradepkg --reinstall clamav-0.91.2-i486-1McD.tgz[0m"
 	echo "	 If Sendmail support is not desired, ignore this warning."
fi

# Update configuration files
{
	upd_conf ${ROOTDIR}etc/clamd.conf
	upd_conf ${ROOTDIR}etc/freshclam.conf
	upd_conf ${ROOTDIR}etc/rc.d/rc.clamav
	upd_conf ${ROOTDIR}etc/cron.daily/clamav-update
	upd_conf ${ROOTDIR}etc/logrotate.d/clamav-milter
} | sed 's/^/[1mConfig alert: [0m/'

# Initialize log files if not already present
upd_conf var/log/clamd > /dev/null 2>&1
upd_conf var/log/clamav-update > /dev/null 2>&1

# Make us start on boot
if ! grep -q "rc.clamav start" etc/rc.d/rc.local; then
 	echo "Adding ClamAV to [4m${ROOTDIR}etc/rc.d/rc.local[0m so it starts at bootup time." 1>&2
 	{	echo ""
 		echo "# ClamAV, the open source anti-virus scanner"
 		echo "test -x /etc/rc.d/rc.clamav && /etc/rc.d/rc.clamav start"
 	} >> etc/rc.d/rc.local
else
 	echo "ClamAV is already in [4metc/rc.d/rc.local[0m."
fi

# Make us stop on shutdown
if ! grep -q "rc.clamav stop" etc/rc.d/rc.local_shutdown 2>/dev/null; then
 	echo "Adding ClamAV to [4metc/rc.d/rc.local_shutdown[0m so it stops at shutdown time." 1>&2
 	{	echo ""
 		echo "# ClamAV, the open source anti-virus scanner"
 		echo "test -x /etc/rc.d/rc.clamav && /etc/rc.d/rc.clamav stop"
 	} >> etc/rc.d/rc.local_shutdown
else
 	echo "ClamAV is already in [4metc/rc.d/rc.local_shutdown[0m."
fi

echo "This package does [1mnot[0m include a virus database."
echo "[1;34mPlease update your virus database now with [31m${CHROOT}/usr/bin/freshclam[0m"

# Make symlinks (generated by makepkg)
( cd usr/lib ; rm -rf libclamav.so.2 )
( cd usr/lib ; ln -sf libclamav.so.2.0.8 libclamav.so.2 )
( cd usr/lib ; rm -rf libclamav.so )
( cd usr/lib ; ln -sf libclamav.so.2.0.8 libclamav.so )
